@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.1
+# Version   : 0.3.2
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -536,64 +536,69 @@ class AFM:
         
         for curve_number in range(0, self.measurements):
 
-            if self.file_name[-3:] != 'nid':
-                _approach = self.approach_raw[:,curve_number]
-                _retract = self.retract_raw[:,curve_number]
-            else:
-                _approach = self.approach_raw[curve_number]
-                _retract = self.retract_raw[curve_number]
-                
-
-            baseline_start = int(len(_approach) * start_pos)
-            baseline_end = int(len(_approach) * end_pos)
-            baseline_region = np.arange(baseline_start,baseline_end)
-
-            _approach_region = _approach[baseline_region]
-            _retract_region = _retract[baseline_region]
-
-            _approach_mean = np.mean(_approach_region)
-
-            adjusted_approach = _approach - _approach_mean
-            adjusted_retract =  _retract - _approach_mean
-
-            approach_dev = np.std(_approach_region)
-            retract_dev = np.std(_retract_region)
-
-            if self.file_name[-3:] != 'nid':
-                _z = self.z_position_raw[:,curve_number]
-            else:
-                _z_a = self.z_approach_raw[curve_number]
-                _z_w = self.z_withdraw_raw[curve_number]
-
-            if len(adjusted_approach) < self.samps_line:
-                blank = np.empty(self.samps_line - len(adjusted_approach))
-                blank[:] = np.nan
-
-                adjusted_approach = np.append(adjusted_approach, blank)
-                _z_a = np.append(_z_a, blank)
-
-            if len(adjusted_retract) < self.samps_line:
-                blank = np.empty(self.samps_line - len(adjusted_retract))
-                blank[:] = np.nan
-                
-                adjusted_retract =  np.append(adjusted_retract, blank)
-                _z_w = np.append(_z_w, blank)
-
-            if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
+            try:
 
                 if self.file_name[-3:] != 'nid':
-                    self.z_approach[:,i] = _z
-                    self.z_withdraw[:,i] = _z
-                    self.approach[:,i] = adjusted_approach
-                    self.retract[:,i] = adjusted_retract
-
+                    _approach = self.approach_raw[:,curve_number]
+                    _retract = self.retract_raw[:,curve_number]
                 else:
-                    self.z_approach[:,i] = _z_a[::-1] * -1 * 1e9
-                    self.z_withdraw[:,i] = _z_w[::-1] * -1 * 1e9
-                    self.approach[:,i] = adjusted_approach[::-1] * 1e9
-                    self.retract[:,i] = adjusted_retract[::-1] * 1e9
+                    _approach = self.approach_raw[curve_number]
+                    _retract = self.retract_raw[curve_number]
+                    
 
-                i += 1
+                baseline_start = int(len(_approach) * start_pos)
+                baseline_end = int(len(_approach) * end_pos)
+                baseline_region = np.arange(baseline_start,baseline_end)
+
+                _approach_region = _approach[baseline_region]
+                _retract_region = _retract[baseline_region]
+
+                _approach_mean = np.mean(_approach_region)
+
+                adjusted_approach = _approach - _approach_mean
+                adjusted_retract =  _retract - _approach_mean
+
+                approach_dev = np.std(_approach_region)
+                retract_dev = np.std(_retract_region)
+
+                if self.file_name[-3:] != 'nid':
+                    _z = self.z_position_raw[:,curve_number]
+                else:
+                    _z_a = self.z_approach_raw[curve_number]
+                    _z_w = self.z_withdraw_raw[curve_number]
+
+                if len(adjusted_approach) < self.samps_line:
+                    blank = np.empty(self.samps_line - len(adjusted_approach))
+                    blank[:] = np.nan
+
+                    adjusted_approach = np.append(adjusted_approach, blank)
+                    _z_a = np.append(_z_a, blank)
+
+                if len(adjusted_retract) < self.samps_line:
+                    blank = np.empty(self.samps_line - len(adjusted_retract))
+                    blank[:] = np.nan
+                    
+                    adjusted_retract =  np.append(adjusted_retract, blank)
+                    _z_w = np.append(_z_w, blank)
+
+                if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
+
+                    if self.file_name[-3:] != 'nid':
+                        self.z_approach[:,i] = _z
+                        self.z_withdraw[:,i] = _z
+                        self.approach[:,i] = adjusted_approach
+                        self.retract[:,i] = adjusted_retract
+
+                    else:
+                        self.z_approach[:,i] = _z_a[::-1] * -1 * 1e9
+                        self.z_withdraw[:,i] = _z_w[::-1] * -1 * 1e9
+                        self.approach[:,i] = adjusted_approach[::-1] * 1e9
+                        self.retract[:,i] = adjusted_retract[::-1] * 1e9
+
+                    i += 1
+            
+            except:
+                print('Error processing force curve number', curve_number, ' (data skipped)') 
 
         self.approach = self.approach[:,:i]
         self.retract = self.retract[:,:i]
